@@ -1,12 +1,12 @@
 ###
-### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
+### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2014
 #
-`nobs.mvmeta` <-
+nobs.mvmeta <-
 function (object, ...) {
 #
 ################################################################################
 # EXTRACTS THE NUMBER OF OBSERVATIONS USED FOR FITTING. USED BY BIC
 #
-   return(object$df$nobs)
+  object$df$nobs
 #
 }
\ No newline at end of file
